One Time Password Authentication
================================

.. image:: https://travis-ci.org/lepture/otpauth.png?branch=master
        :target: https://travis-ci.org/lepture/otpauth
.. image:: https://coveralls.io/repos/lepture/otpauth/badge.png?branch=master
        :target: https://coveralls.io/r/lepture/otpauth


Installation
------------

To install otpauth, simply::

    $ pip install otpauth


Contribute
----------

Read the `Contribution Guide`_.

.. _`Contribution Guide`: https://github.com/lepture/otpauth/blob/master/CONTRIBUTING.rst
